@@ -33,10 +33,9 @@ class Logger:
                     source = source.replace(commompath,'')
                 except:
                     pass
-
-            if not 'SOURCE_FOLDER' in os.environ:
-                source = source.replace('venv\\lib\\site-packages\\','')
-                source = source.replace('Windows\\system32\\','')
+            
+            source = source.replace('venv\\lib\\site-packages\\','')
+            source = source.replace('Windows\\system32\\','')
 
             if not user is None:                
                 Logger.user = user
@@ -109,7 +108,7 @@ class Logger:
             source = f[lenlogsdir+1:].replace('.log','.py')
             try:
                 _df = pd.read_csv(f,header=None,sep=';',\
-                    engine='python',error_bad_lines=False,warn_bad_lines=False)
+                    engine='python',on_bad_lines='skip')
                 _df.columns = ['user','datetime','name','type','message']
                 _df['source'] = source
                 df = df.append(_df)
