@@ -53,7 +53,8 @@ class Metadata():
         self.path = self.fpath /  ('Metadata/'+self.name+'.pkl')
         
         if not self.path.parent.exists():
-            self.path.parent.mkdir(parents=True, exist_ok=True)
+            if self.save_local:
+                self.path.parent.mkdir(parents=True, exist_ok=True)
         
         readpkl=True
         readxlsx=False
@@ -63,7 +64,7 @@ class Metadata():
             readpkl = self.path.is_file()
             readxlsx = self.pathxls.is_file()
             if (readpkl) & (readxlsx):
-                readxlsx = os.path.getmtime(self.pathxls)>os.path.getmtime(self.pathpkl)
+                readxlsx = os.path.getmtime(self.pathxls)>os.path.getmtime(self.path)
                 readpkl = not readxlsx
                         
         if (not readxlsx) | (not self.save_local):
@@ -149,22 +150,23 @@ class Metadata():
 
     def save_metadata(self,save_excel=False):
         fpath = Path(os.environ['DATABASE_FOLDER']) / self.user
-        pathxls = fpath /  ('Metadata/'+self.name+'.xlsx')
-        path = fpath /  ('Metadata/'+self.name+'.pkl')
+        self.pathxls = fpath /  ('Metadata/'+self.name+'.xlsx')
+        self.path = fpath /  ('Metadata/'+self.name+'.pkl')
 
         tini = time.time()
-        if not os.path.isdir(path.parents[0]):
-            os.makedirs(path.parents[0])
+        mtime = datetime.now().timestamp()
+        if not os.path.isdir(self.path.parents[0]):
+            os.makedirs(self.path.parents[0])
         # save excel first so that last modified
         # timestamp is older
         if save_excel:
             with open(self.pathxls, 'wb') as f:
                 writer = pd.ExcelWriter(f, engine='xlsxwriter')            
                 self.static.to_excel(writer,sheet_name='static')
-                writer.save()                
+                writer.close()
                 f.flush()
+            os.utime(self.pathxls, (mtime, mtime))
         
-        mtime = datetime.now().timestamp()
         
         pkl_io = None
         if self.save_local:            
@@ -176,7 +178,7 @@ class Metadata():
                 f.write(pkl_io.getbuffer())
                 f.flush()
                 f.close()
-            os.utime(path, (mtime, mtime))
+            os.utime(self.path, (mtime, mtime))
 
         if self.s3write:
             if pkl_io is None:
@@ -187,22 +189,11 @@ class Metadata():
             gzip_io = io.BytesIO()
             with gzip.GzipFile(fileobj=gzip_io, mode='wb', compresslevel=1) as gz:
                 shutil.copyfileobj(pkl_io, gz)                        
-            S3Upload(gzip_io, str(path)+'.gzip', mtime)
+            S3Upload(gzip_io, str(self.path)+'.gzip', mtime)
 
         if not pkl_io is None:
             io.BytesIO.close(gzip_io)
 
-        # if self.save_local:            
-        #     self.static.to_pickle(path)
-        #     os.utime(path, (mtime, mtime))
-
-        # if self.s3write:            
-        #     io_obj = io.BytesIO()
-        #     io_obj.close = lambda: None
-        #     self.static.to_pickle(io_obj,compression='gzip')
-        #     S3Upload(io_obj, str(path)+'.gzip', mtime)
-        #     io.BytesIO.close(io_obj)
-
         if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Saving metadata ' + self.name + ' %.2f done!' % (time.time()-tini))
 
