@@ -200,19 +200,22 @@ def S3Download(local_path, remote_path, force_download=False):
     remote_isnewer = False
     local_exists = os.path.isfile(str(local_path))
     local_mtime = None
-    if local_exists:        
+    if local_exists:
         # local mtime
         local_mtime = datetime.utcfromtimestamp(os.path.getmtime(local_path)).timestamp()        
+        
+    if (local_exists) & (remote_exists):
         #compare
-        remote_isnewer = remote_mtime>local_mtime        
+        remote_isnewer = remote_mtime>local_mtime   
 
-    if ((not local_exists) & remote_exists) | (remote_isnewer) | (force_download):
-        io_obj = io.BytesIO()
-        try:            
-            obj.download_fileobj(io_obj)
-            return [io_obj , local_mtime, remote_mtime]
-        except Exception as e:
-            raise Exception('downloading %s,%s ERROR!\n%s' % (Logger.user,local_path,str(e)))
+    if remote_exists:
+        if (not local_exists) | (remote_isnewer) | (force_download):
+            io_obj = io.BytesIO()
+            try:            
+                obj.download_fileobj(io_obj)
+                return [io_obj , local_mtime, remote_mtime]
+            except Exception as e:
+                raise Exception('downloading %s,%s ERROR!\n%s' % (Logger.user,local_path,str(e)))
         
     return [None, local_mtime, remote_mtime]
 
