@@ -63,16 +63,12 @@ class SharedDataFeeder():
         
         if tags is None:            
             idx = self.dataset['period'] == period
-            # create a thread pool
-            with ThreadPoolExecutor(self.dataset.shape[0]) as exe:            
-                futures = [exe.submit(self.load_tag, period, tag) for tag in self.dataset['tag'][idx]]
-                # collect data
-                data = [future.result() for future in futures]
-        else:            
-            # create a thread pool
-            with ThreadPoolExecutor(len(tags)) as exe:            
-                futures = [exe.submit(self.load_tag, period, tag) for tag in tags]
-                # collect data
+            tags = self.dataset['tag'][idx].values
+        
+        n_workers = len(tags)
+        if n_workers>0:
+            with ThreadPoolExecutor(n_workers) as exe:
+                futures = [exe.submit(self.load_tag, period, tag) for tag in tags]                
                 data = [future.result() for future in futures]
          
     def load_tag(self,period,tag):        
@@ -88,19 +84,13 @@ class SharedDataFeeder():
             self.sharedData.getMetadata(c)
 
         if tags is None:
-            # create a thread pool
-            if len(self[period].tags)>0:
-                with ThreadPoolExecutor(len(self[period].tags)) as exe:
-                    futures = [exe.submit(self.save_tag, period, tag, startDate) for tag in self[period].tags.keys()]
-                    # collect data
-                    data = [future.result() for future in futures]
-        else:            
-            if len(tags)>0:
-                # create a thread pool
-                with ThreadPoolExecutor(len(tags)) as exe:            
-                    futures = [exe.submit(self.save_tag, period, tag, startDate) for tag in tags]
-                    # collect data
-                    data = [future.result() for future in futures]
+            tags = self[period].tags.keys()
+            
+        n_workers = len(tags)
+        if n_workers>0:
+            with ThreadPoolExecutor(n_workers) as exe:
+                futures = [exe.submit(self.save_tag, period, tag, startDate) for tag in tags]
+                data = [future.result() for future in futures]
 
     def save_tag(self, period, tag, startDate=None):
         if startDate is None:
