@@ -64,7 +64,8 @@ class SharedDataFrame:
         shm_name = shm_name + '/' + self.sharedData.database
         shm_name = shm_name + '/' + self.sharedDataFeeder.feeder
         shm_name = shm_name + '/' + self.period + '/' + self.tagstr
-        shm_name = shm_name.replace('\\','/')
+        if os.name=='posix':
+            shm_name = shm_name.replace('/','\\')
 
         if not iswrite:
             if 'LEGACY_READ' in os.environ:
@@ -82,8 +83,9 @@ class SharedDataFrame:
         path = path / self.sharedDataFeeder.feeder
         path = path / self.period
         path = Path(str(path).replace('\\','/'))
-        if not os.path.isdir(path):
-            os.makedirs(path)
+        if self.sharedData.save_local:
+            if not os.path.isdir(path):
+                os.makedirs(path)
 
         return path, shm_name
 
