@@ -96,9 +96,10 @@ class SharedDataTimeSeries:
         self.init_time = time.time() - self.init_time
 
     def getDataPath(self, iswrite=False):
-        shm_name = self.sharedData.user + '\\' + self.sharedData.database + '\\' \
-            + self.sharedDataFeeder.feeder + '\\' + self.period + '\\' + self.tag
-        shm_name = shm_name.replace('\\','/')
+        shm_name = self.sharedData.user + '/' + self.sharedData.database + '/' \
+            + self.sharedDataFeeder.feeder + '/' + self.period + '/' + self.tag
+        if os.name=='posix':
+            shm_name = shm_name.replace('/','\\')
         
         if not iswrite:
             if 'LEGACY_READ' in os.environ:
@@ -111,10 +112,15 @@ class SharedDataTimeSeries:
             else:
                 path = Path(os.environ['DATABASE_FOLDER'])
 
-        path = path / shm_name
-        #path = Path(str(path).replace('\\','/'))        
-        if not os.path.isdir(path):
-            os.makedirs(path)
+        path = path / self.sharedData.user
+        path = path / self.sharedData.database
+        path = path / self.sharedDataFeeder.feeder
+        path = path / self.period
+        path = path / self.tag
+        path = Path(str(path).replace('\\','/'))
+        if self.sharedData.save_local:
+            if not os.path.isdir(path):
+                os.makedirs(path)
         
         return path, shm_name
 
@@ -285,7 +291,8 @@ class SharedDataTimeSeries:
         tini=time.time()
         
         #Create write ndarray
-        path, shm_name = self.getDataPath(iswrite=True)        
+        path, shm_name = self.getDataPath(iswrite=True)
+        
         if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Malloc %s ...%.2f%% ' % (shm_name,0.0))
 
